@@ -208,6 +208,34 @@ void AbstractSpiceKernel::startNetlist(QTextStream &stream, bool xyce)
             }
         }
 
+        // create .IC from wire labels
+        QStringList wire_labels;
+        for(Wire *pw = Sch->DocWires.first(); pw != 0; pw = Sch->DocWires.next()) {
+            if (pw->Label != nullptr) {
+                QString label = pw->Label->Name;
+                if (!wire_labels.contains(label)) wire_labels.append(label);
+                else continue;
+                QString ic = pw->Label->initValue;
+                if (!ic.isEmpty()) {
+                    QString ic_str = QString(".IC v(%1)=%2\n").arg(label).arg(ic);
+                    stream<<ic_str;
+                }
+            }
+        }
+        for(Node *pn = Sch->DocNodes.first(); pn != 0; pn = Sch->DocNodes.next()) {
+            Conductor *pw = (Conductor*) pn;
+            if (pw->Label != nullptr) {
+                QString label = pw->Label->Name;
+                if (!wire_labels.contains(label)) wire_labels.append(label);
+                else continue;
+                QString ic = pw->Label->initValue;
+                if (!ic.isEmpty()) {
+                    QString ic_str = QString(".IC v(%1)=%2\n").arg(label).arg(ic);
+                    stream<<ic_str;
+                }
+            }
+        }
+
         // Parameters, Initial conditions, Options
         for(Component *pc = Sch->DocComps.first(); pc != 0; pc = Sch->DocComps.next()) {
             if (pc->isEquation) {
@@ -291,9 +319,7 @@ void AbstractSpiceKernel::createSubNetlsit(QTextStream &stream, bool lib)
     header += "\n";
     if (lib) stream<<"\n";
     stream<<header;
-    bool xyce = false;
-    if ((QucsSettings.DefaultSimulator == spicecompat::simXyceSer)||
-        (QucsSettings.DefaultSimulator == spicecompat::simXycePar)) xyce = true;
+    bool xyce = QucsSettings.DefaultSimulator == spicecompat::simXyce;
     startNetlist(stream,xyce);
     stream<<".ENDS\n";
 }
@@ -486,8 +512,7 @@ void AbstractSpiceKernel::parseFourierOutput(QString ngspice_file, QList<QList<d
                 if (ss.endsWith(',')) ss.chop(1);
                 Nharm = ss.toInt();
                 while (!ngsp_data.readLine().contains(QRegularExpression("Harmonic\\s+Frequency")));
-                if (!(QucsSettings.DefaultSimulator == spicecompat::simXyceSer||
-                      QucsSettings.DefaultSimulator == spicecompat::simXycePar)) lin = ngsp_data.readLine(); // dummy line
+                if (QucsSettings.DefaultSimulator != spicecompat::simXyce) lin = ngsp_data.readLine(); // dummy line
                 for (int i=0;i<Nharm;i++) {
                     lin = ngsp_data.readLine();
                     if (!firstgroup) {
@@ -1244,6 +1269,11 @@ void AbstractSpiceKernel::convertToQucsData(const QString &qucs_dataset)
         QTextStream ts(&dataset);
         ts<<ds_str;
         dataset.close();
+    } else {
+        QFileInfo inf(qucs_dataset);
+        QMessageBox::warning(nullptr, tr("Simulate"),
+                             tr("Failed to create dataset file ") + qucs_dataset + "\n"
+                             + tr("Check write permission of the directory ") + inf.path());
     }
 #ifdef NDEBUG
     removeAllSimulatorOutputs();
