@@ -79,6 +79,10 @@ bool loadSettings()
         QucsSettings.DefaultSimulator = settings.value("DefaultSimulator").toInt();
     else QucsSettings.DefaultSimulator = spicecompat::simNotSpecified;
 
+    if(settings.contains("firstRun"))
+        QucsSettings.firstRun = settings.value("firstRun").toBool();
+    else QucsSettings.firstRun = true;
+
     if(settings.contains("x"))QucsSettings.x=settings.value("x").toInt();
     if(settings.contains("y"))QucsSettings.y=settings.value("y").toInt();
     if(settings.contains("dx"))QucsSettings.dx=settings.value("dx").toInt();
@@ -130,14 +134,10 @@ bool loadSettings()
     if(settings.contains("NgspiceExecutable")) QucsSettings.NgspiceExecutable = settings.value("NgspiceExecutable").toString();
     else {
 #ifdef Q_OS_WIN
-        QString ngsp_base = "ngspice_con";
+        QucsSettings.NgspiceExecutable = "ngspice_con.exe";
 #else
-        QString ngsp_base = "ngspice";
+        QucsSettings.NgspiceExecutable = "ngspice";
 #endif
-        QString ngsp_exe = QCoreApplication::applicationDirPath() +
-                QDir::separator() + ngsp_base + executableSuffix;
-        if (!QFile::exists(ngsp_exe)) ngsp_exe = QString("ngspice") + executableSuffix;
-        QucsSettings.NgspiceExecutable = ngsp_exe;
     }
     if(settings.contains("XyceExecutable")) QucsSettings.XyceExecutable = settings.value("XyceExecutable").toString();
     else {
@@ -189,10 +189,11 @@ bool loadSettings()
     if (settings.contains("fullTraceName")) QucsSettings.fullTraceName = settings.value("fullTraceName").toBool();
     else QucsSettings.fullTraceName = false;
 
-    QucsSettings.FileToolbar = settings.contains("FileToolbar") ? settings.value("FileToolbar").toBool() : true;
-    QucsSettings.EditToolbar = settings.contains("EditToolbar") ? settings.value("EditToolbar").toBool() : true;
-    QucsSettings.ViewToolbar = settings.contains("ViewToolbar") ? settings.value("ViewToolbar").toBool() : true;
-    QucsSettings.WorkToolbar = settings.contains("WorkToolbar") ? settings.value("WorkToolbar").toBool() : true;
+    QucsSettings.FileToolbar = !settings.contains("FileToolbar") || settings.value("FileToolbar").toBool();
+    QucsSettings.EditToolbar = !settings.contains("EditToolbar") || settings.value("EditToolbar").toBool();
+    QucsSettings.ViewToolbar = !settings.contains("ViewToolbar") || settings.value("ViewToolbar").toBool();
+    QucsSettings.WorkToolbar = !settings.contains("WorkToolbar") || settings.value("WorkToolbar").toBool();
+    QucsSettings.SimulateToolbar = !settings.contains("SimulateToolbar") || settings.value("SimulateToolbar").toBool();
 
     QucsSettings.RecentDocs = settings.value("RecentDocs").toString().split("*",qucs::SkipEmptyParts);
     QucsSettings.numRecentDocs = QucsSettings.RecentDocs.count();
@@ -223,6 +224,7 @@ bool saveApplSettings()
     QSettings settings ("qucs","qucs_s");
 
     settings.setValue("DefaultSimulator", QucsSettings.DefaultSimulator);
+    settings.setValue("firstRun", false);
 
     settings.setValue("x", QucsSettings.x);
     settings.setValue("y", QucsSettings.y);
@@ -279,6 +281,7 @@ bool saveApplSettings()
     settings.setValue("EditToolbar", QucsSettings.EditToolbar);
     settings.setValue("ViewToolbar", QucsSettings.ViewToolbar);
     settings.setValue("WorkToolbar", QucsSettings.WorkToolbar);
+    settings.setValue("SimulateToolbar", QucsSettings.SimulateToolbar);
 
     // Copy the list of directory paths in which Qucs should
     // search for subcircuit schematics from qucsPathList
@@ -347,7 +350,7 @@ Schematic *openSchematic(QString schematic)
   }
 
   // populate Modules list
-  Module::registerModules ();
+  //Module::registerModules ();
 
   // new schematic from file
   Schematic *sch = new Schematic(0, schematic);
@@ -444,7 +447,7 @@ int runNgspice(QString schematic, QString dataset)
 
 int runXyce(QString schematic, QString dataset)
 {
-    QucsSettings.DefaultSimulator = spicecompat::simXyceSer;
+    QucsSettings.DefaultSimulator = spicecompat::simXyce;
     Schematic *sch = openSchematic(schematic);
     if (sch == NULL) {
       return 1;
@@ -482,7 +485,7 @@ int doNgspiceNetlist(QString schematic, QString netlist)
 
 int doXyceNetlist(QString schematic, QString netlist)
 {
-    QucsSettings.DefaultSimulator = spicecompat::simXyceSer;
+    QucsSettings.DefaultSimulator = spicecompat::simXyce;
     Schematic *sch = openSchematic(schematic);
     if (sch == NULL) {
       return 1;
@@ -843,6 +846,7 @@ int main(int argc, char *argv[])
   // load existing settings (if any)
   loadSettings();
 
+
   // continue to set up overrides or default settings (some are saved on exit)
 
   // check for relocation env variable
