@@ -641,7 +641,9 @@ void QucsApp::slotSelectAll()
     ((TextDoc*)Doc)->selectAll();
   }
   else {
-    ((Schematic*)Doc)->selectElements(INT_MIN, INT_MIN, INT_MAX, INT_MAX, true, false);
+    int xmin, ymin, xmax, ymax;
+    ((Schematic*)Doc)->sizeOfAll(xmin, ymin, xmax, ymax);
+    ((Schematic*)Doc)->selectElements(xmin, ymin, xmax, ymax, true, false);
     ((Schematic*)Doc)->viewport()->update();
     view->drawn = false;
   }
@@ -667,7 +669,7 @@ extern QString lastDirOpenSave; // to remember last directory and file
 // component edit dialog.
 void QucsApp::editFile(const QString& File)
 {
-    if ((QucsSettings.Editor.toLower() == "qucs") | QucsSettings.Editor.isEmpty())
+    if ((QucsSettings.Editor.toLower() == "qucs") || QucsSettings.Editor.isEmpty())
     {
         // The Editor is 'qucs' or empty, open a net document tab
         if (File.isEmpty()) {
@@ -755,8 +757,7 @@ void QucsApp::slotShowLastNetlist()
 
     QWidget *w = DocumentTab->currentWidget();
 
-    if (QucsSettings.DefaultSimulator == spicecompat::simXycePar ||
-            QucsSettings.DefaultSimulator == spicecompat::simXyceSer) {
+    if (QucsSettings.DefaultSimulator == spicecompat::simXyce) {
         if (isTextDocument(w)) {
             QMessageBox::information(this, tr("Show netlist"),
                                      tr("Not a schematic tab!"));
@@ -778,8 +779,7 @@ void QucsApp::slotShowLastNetlist()
         netlists.append(QDir::toNativeSeparators(QucsSettings.S4Qworkdir
                                                  + "/spice4qucs.cir"));
         break;
-    case spicecompat::simXycePar: // Xyce generates one netlist for
-    case spicecompat::simXyceSer: // every simulation
+    case spicecompat::simXyce: // Xyce generates one netlist for every simulation
         for(const auto &sim : sim_lst) {
             netlists.append(QDir::toNativeSeparators(QucsSettings.S4Qworkdir
                                                      + "/spice4qucs."
@@ -977,8 +977,8 @@ void QucsApp::slotAddToProject()
 
     if(destFile.exists())
       if(QMessageBox::information(this, tr("Overwrite"),
-           tr("File \"%1\" already exists.\nOverwrite ?").arg(*it), QMessageBox::Yes,
-           QMessageBox::No|QMessageBox::Default|QMessageBox::Escape)
+           tr("File \"%1\" already exists.\nOverwrite ?").arg(*it),
+           QMessageBox::Yes|QMessageBox::No)
          != QMessageBox::Yes) {
         origFile.close();
         it++;
@@ -1306,7 +1306,7 @@ void QucsApp::slotExportGraphAsCsv()
   if(File.exists())
     if(QMessageBox::information(this, tr("Info"),
           tr("Output file already exists!")+"\n"+tr("Overwrite it?"),
-          tr("&Yes"), tr("&No"), 0,1,1))
+          QMessageBox::Yes|QMessageBox::No) == QMessageBox::No)
       return;
 
   if(!File.open(QIODevice::WriteOnly)) {
