@@ -573,7 +573,7 @@ void QucsApp::initActions()
   showNet->setWhatsThis(tr("Show Last Netlist\n\nShows the netlist of the last simulation"));
   connect(showNet, SIGNAL(triggered()), SLOT(slotShowLastNetlist()));
 
-  simSettings = new QAction(tr("Select default simulator"),this);
+  simSettings = new QAction(tr("Simulators Settings..."),this);
   connect(simSettings,SIGNAL(triggered()),SLOT(slotSimSettings()));
   buildVAModule = new QAction(tr("Build Verilog-A module from subcircuit"),this);
   connect(buildVAModule,SIGNAL(triggered()),SLOT(slotBuildVAModule()));
@@ -915,18 +915,21 @@ void QucsApp::initToolBar()
   workToolbar->addAction(insEquation);
   workToolbar->addAction(insGround);
   workToolbar->addAction(insPort);
-  workToolbar->addAction(simulate);
-  workToolbar->addAction(dpl_sch);
-  workToolbar->addAction(setMarker);
-  workToolbar->addSeparator();    // <<<=======================
+  //workToolbar->addSeparator();    // <<<=======================
 
+  simulateToolbar = new QToolBar(tr("Simulate"));
+  this->addToolBar(simulateToolbar);
+  simulateToolbar->addWidget(reinterpret_cast<QWidget *>(simulatorsCombobox));
+  simulateToolbar->addAction(simulate);
+  simulateToolbar->addAction(dpl_sch);
+  simulateToolbar->addAction(setMarker);
 }
 
 // ----------------------------------------------------------
 void QucsApp::initStatusBar()
 {
   // To reserve enough space, insert the longest text and rewrite it afterwards.
-  SimulatorLabel = new QLabel(spicecompat::getDefaultSimulatorName());
+  SimulatorLabel = new QLabel(spicecompat::getDefaultSimulatorName(QucsSettings.DefaultSimulator));
   statusBar()->addPermanentWidget(SimulatorLabel, 0);
 
   WarningLabel = new QLabel(tr("no warnings"), statusBar());
@@ -1004,6 +1007,7 @@ void QucsApp::slotViewToolBar(bool toggle)
   editToolbar->setVisible(toggle);
   viewToolbar->setVisible(toggle);
   workToolbar->setVisible(toggle);
+  simulateToolbar->setVisible(toggle);
 }
 
 // ----------------------------------------------------------
