@@ -2088,18 +2088,26 @@ void Schematic::contentsDropEvent(QDropEvent *Event)
   }
 
 
-  QMouseEvent e(QEvent::MouseButtonPress, Event->pos(),
+#if QT_VERSION >= 0x060000
+  auto ev_pos = Event->position();
+#else
+  auto ev_pos = Event->pos();
+#endif
+  QMouseEvent e(QEvent::MouseButtonPress, ev_pos,
                 Qt::LeftButton, Qt::NoButton, Qt::NoModifier);
-  int x = int(Event->pos().x()/Scale) + ViewX1;
-  int y = int(Event->pos().y()/Scale) + ViewY1;
+  int x = int(ev_pos.x()/Scale) + ViewX1;
+  int y = int(ev_pos.y()/Scale) + ViewY1;
 
   App->view->MPressElement(this, &e, x, y);
 
   delete App->view->selElem;
   App->view->selElem = nullptr;  // no component selected
 
-  if(formerAction)
-    formerAction->setChecked(true);  // restore old action
+    if (formerAction) {
+        formerAction->setChecked(true);
+    } else {
+        QucsMain->select->setChecked(true);  // restore old action
+    }
 }
 
 // ---------------------------------------------------
@@ -2179,8 +2187,13 @@ void Schematic::contentsDragMoveEvent(QDragMoveEvent *Event)
       return;
     }
 
-    QMouseEvent e(QEvent::MouseMove, Event->pos(), Qt::NoButton, 
+#if QT_VERSION >= 0x060000
+    QMouseEvent e(QEvent::MouseMove, Event->position(), Qt::NoButton,
 		  Qt::NoButton, Qt::NoModifier);
+#else
+    QMouseEvent e(QEvent::MouseMove, Event->pos(), Qt::NoButton,
+          Qt::NoButton, Qt::NoModifier);
+#endif
     App->view->MMoveElement(this, &e);
   }
 
